@@ -3,7 +3,7 @@ package Net::MQTT::Simple;
 use strict;
 use warnings;
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 # Please note that these are not documented and are subject to change:
 our $KEEPALIVE_INTERVAL = 60;
@@ -27,8 +27,8 @@ sub _default_port { 1883 }
 sub _socket_error { "$@" }
 sub _secure { 0 }
 
-my $random_id = join "", map chr 65 + int rand 26, 1 .. 10;
-sub _client_identifier { "Net::MQTT::Simple[$random_id]" }
+
+sub _client_identifier { my ($class) = @_; return "Net::MQTT::Simple[" . $class->{random_id} . "]"; }
 
 # Carp might not be available either.
 sub _croak {
@@ -76,10 +76,14 @@ sub new {
     # Add port for bare IPv4 address or bracketed IPv6 address
     $server .= ":$port" if $server !~ /:/ or $server =~ /^\[.*\]$/;
 
+	# Create a random ID for the instance of the object
+	my $random_id = join "", map chr 65 + int rand 26, 1 .. 10;
+	
     return bless {
         server       => $server,
         last_connect => 0,
         sockopts     => $sockopts // {},
+        random_id    => $random_id
     }, $class;
 }
 
@@ -392,8 +396,9 @@ sub unsubscribe {
     $self->_send_unsubscribe(@topics);
 
     my $cb = $self->{callbacks};
-    @$cb = grep $_->{topic} ne $_, @$cb
-        for @topics;
+    for my $topic ( @topics ) {
+      @$cb = grep {$_->{topic} ne $topic} @$cb;
+    }
 
     delete @{ $self->{sub} }{ @topics };
 }
